@@ -1,7 +1,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;; CNESL mode for editing, interpreting.
+;;; NESL mode for editing, interpreting.
 ;;;
-;;; CNESL formatting by Tom Sheffler.
+;;; NESL formatting by Tom Sheffler.
 ;;; Built on initial version by Guy Blelloch.
 ;;; Feb 1993
 ;;;
@@ -13,72 +13,92 @@
 ;;; 	Pretty print in a popup window. 
 ;;;
 ;;; V 1.0: Tom Sheffler, Feb 1993
-;;; 	Basic CNESL indentation code.
+;;; 	Basic NESL indentation code.
 ;;; 	Comment syntax.
 ;;;
 ;;; V 0.9: Guy Blelloch created, basic send-defun
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(setq auto-mode-alist (append '(("\\.cnesl$" . cnesl-mode)) auto-mode-alist))
+;;; To speed things up and only autoload the code when its needed, do this:
+;;; 1) Copy nesl-mode.el and nesl.el to your emacs-lisp source directory.
+;;;    If you don't have one, you can create one with the following:
+;;;     a) mkdir ~/emacs       [or wherever you want to put it]
+;;;     b) add the following line (without the ;;;) to your .emacs file
+;;;        (setq load-path (append (expand-file-name "~/emacs") load-path))
+;;; 2) Comment out the line 10 lines below this one with a ;
+;;; 3) From within GNU Emacs, byte-compile the files (M-x byte-compile,
+;;;    ~/emacs/nesl-mode.el and M-x byte-compile, ~/emacs-nesl.el
+;;; 4) Add the following four lines (without the ;;;) to your .emacs file:
+;;;    (autoload 'run-nesl "nesl" "Major mode for running a NESL process." t)
+;;;    (autoload 'nesl-mode "nesl-mode" "Major mode for editting NESL code." t)
+;;;    (setq auto-mode-alist (append '(("\\.nesl$" . nesl-mode)) 
+;;;                                   auto-mode-alist))
+
+;;; Comment out the following line (put a ";" at its beginning) if auto-loading
+(setq auto-mode-alist (append '(("\\.nesl$" . nesl-mode)) auto-mode-alist))
 
 ;;; Mode Variables
-(defconst cnesl-indent-level 4
-  "*Indentation to be used inside of Cnesl blocks or arrays")
+(defconst nesl-indent-level 4
+  "*Indentation to be used inside of Nesl blocks or arrays")
 
-(defconst cnesl-tab-width 4
-  "*Tab stop width for Cnesl mode")
+(defconst nesl-tab-width 4
+  "*Tab stop width for Nesl mode")
 
-(defun cnesl-make-tabs (stop)
-  (and (< stop 132) (cons stop (cnesl-make-tabs (+ stop cnesl-tab-width)))))
+(defconst nesl-scroll-after-send-defun nil
+  "If t, forces redisplay and scrolling of *nesl* buffer")
 
-(defconst cnesl-tab-stop-list (cnesl-make-tabs cnesl-tab-width)
-  "*Tab stop list for cnesl mode")
+(defun nesl-make-tabs (stop)
+  (and (< stop 132) (cons stop (nesl-make-tabs (+ stop nesl-tab-width)))))
 
-(defvar cnesl-tab-always-indent t
+(defconst nesl-tab-stop-list (nesl-make-tabs nesl-tab-width)
+  "*Tab stop list for nesl mode")
+
+(defvar nesl-tab-always-indent t
   "TAB keys means always re-indent current line rather than insert TAB.")
 
 (defvar nesl-process "nesl"
   "String name of process that is inferior Nesl")
 
-(defvar cnesl-mode-hook nil
-  "User-definable function hook called on entry to cnesl-mode")
+(defvar nesl-mode-hook nil
+  "User-definable function hook called on entry to nesl-mode")
 
-(defvar cnesl-mode-map nil
-  "Key map for CNESL mode.")
+(defvar nesl-mode-map nil
+  "Key map for NESL mode.")
+
+(defvar nesl-mode-syntax-table nil
+  "Syntax table in use in Nesl-mode buffers.")
 
-(defvar cnesl-mode-syntax-table nil
-  "Syntax table in use in CNesl-mode buffers.")
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(if cnesl-mode-map			; set once upon loading
+(if nesl-mode-map			; set once upon loading
     ()
-  (setq cnesl-mode-map (make-sparse-keymap))
-  (define-key cnesl-mode-map "\e\C-x"	'cnesl-send-defun)
-  (define-key cnesl-mode-map "\e\C-a"	'beginning-of-cnesl-function)
-  (define-key cnesl-mode-map "\e\C-e"	'end-of-cnesl-function)
-  (define-key cnesl-mode-map "\t"   	'cnesl-indent-command)
-  (define-key cnesl-mode-map "\C-cp" 	'cnesl-pretty-print-defun)
-  (define-key cnesl-mode-map "\C-ct" 	'cnesl-insert-function-type)
+  (setq nesl-mode-map (make-sparse-keymap))
+  (define-key nesl-mode-map "\e\C-x"	'nesl-send-defun-and-maybe-scroll)
+  (define-key nesl-mode-map "\e\C-a"	'beginning-of-nesl-function)
+  (define-key nesl-mode-map "\e\C-e"	'end-of-nesl-function)
+  (define-key nesl-mode-map "\t"   	'nesl-indent-command)
+  (define-key nesl-mode-map "\C-cp" 	'nesl-pretty-print-defun)
+  (define-key nesl-mode-map "\C-ct" 	'nesl-insert-function-type)
   )
 
-(if cnesl-mode-syntax-table		; set once upon loading
+(if nesl-mode-syntax-table		; set once upon loading
     ()
-  (setq cnesl-mode-syntax-table (make-syntax-table))
-  (modify-syntax-entry ?_ "w" cnesl-mode-syntax-table)
-  (modify-syntax-entry ?\\ "\\" cnesl-mode-syntax-table)
-  (modify-syntax-entry ?/ "." cnesl-mode-syntax-table)
-  (modify-syntax-entry ?* "." cnesl-mode-syntax-table)
-  (modify-syntax-entry ?+ "." cnesl-mode-syntax-table)
-  (modify-syntax-entry ?- "." cnesl-mode-syntax-table)
-  (modify-syntax-entry ?= "." cnesl-mode-syntax-table)
-  (modify-syntax-entry ?% "$" cnesl-mode-syntax-table)
-  (modify-syntax-entry ?< "." cnesl-mode-syntax-table)
-  (modify-syntax-entry ?> "." cnesl-mode-syntax-table)
-  (modify-syntax-entry ?& "." cnesl-mode-syntax-table)
-  (modify-syntax-entry ?| "." cnesl-mode-syntax-table))
+  (setq nesl-mode-syntax-table (make-syntax-table))
+  (modify-syntax-entry ?_ "w" nesl-mode-syntax-table)
+  (modify-syntax-entry ?\\ "\\" nesl-mode-syntax-table)
+  (modify-syntax-entry ?/ "." nesl-mode-syntax-table)
+  (modify-syntax-entry ?* "." nesl-mode-syntax-table)
+  (modify-syntax-entry ?+ "." nesl-mode-syntax-table)
+  (modify-syntax-entry ?- "." nesl-mode-syntax-table)
+  (modify-syntax-entry ?= "." nesl-mode-syntax-table)
+  (modify-syntax-entry ?% "$" nesl-mode-syntax-table)
+  (modify-syntax-entry ?< "." nesl-mode-syntax-table)
+  (modify-syntax-entry ?> "." nesl-mode-syntax-table)
+  (modify-syntax-entry ?& "." nesl-mode-syntax-table)
+  (modify-syntax-entry ?| "." nesl-mode-syntax-table))
 
-(defun cnesl-mode-variables ()
-  "Function that sets local CNESL mode variables."
+(defun nesl-mode-variables ()
+  "Function that sets local NESL mode variables."
   (make-local-variable 'comment-start)
   (make-local-variable 'comment-end)
   (make-local-variable 'comment-start-skip)
@@ -90,17 +110,17 @@
 	comment-end " %"
 	comment-start-skip "%<? *"	; Regexp to skip until comment body
 	comment-column 40
-    	comment-indent-hook 'cnesl-comment-indent
-	indent-line-function 'cnesl-indent-line
-	tab-stop-list cnesl-tab-stop-list
+    	comment-indent-hook 'nesl-comment-indent
+	indent-line-function 'nesl-indent-line
+	tab-stop-list nesl-tab-stop-list
 	)
   )
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-(defun cnesl-indent-command (&optional whole-exp)
+(defun nesl-indent-command (&optional whole-exp)
   (interactive "P")
-  "Indent current line as Cnesl code, or in some cases insert a tab character.
-If cnesl-tab-always-indent is non-nil (the default), always indent current line.
+  "Indent current line as Nesl code, or in some cases insert a tab character.
+If nesl-tab-always-indent is non-nil (the default), always indent current line.
 Otherwise, indent the current line only if point is at the left margin
 or in the line's indentation; otherwise insert a tab.
 
@@ -109,12 +129,12 @@ means indent rigidly all the lines of the expression starting after point
 so that this line becomes properly indented.
 The relative indentation among the lines of the expression are preserved."
   (if whole-exp
-      ;; If arg, always indent this line as CNESL
+      ;; If arg, always indent this line as NESL
       ;; and shift remaining lines of expression the same amount.
-      (let ((shift-amt (cnesl-indent-line))
+      (let ((shift-amt (nesl-indent-line))
 	    beg end)
 	(save-excursion
-	  (if cnesl-tab-always-indent
+	  (if nesl-tab-always-indent
 	      (beginning-of-line))
 	  (setq beg (point))
 	  (forward-sexp 1)
@@ -124,17 +144,17 @@ The relative indentation among the lines of the expression are preserved."
 	  (setq beg (point)))
 	(if (> end beg)
 	    (indent-code-rigidly beg end shift-amt "%<")))
-    (if (and (not cnesl-tab-always-indent)
+    (if (and (not nesl-tab-always-indent)
 	     (save-excursion
 	       (skip-chars-backward " \t")
 	       (not (bolp))))
 	(insert-tab)
-      (cnesl-indent-line))))
+      (nesl-indent-line))))
 
-(defun cnesl-indent-line ()
-  "Indent current line as CNesl code.
+(defun nesl-indent-line ()
+  "Indent current line as Nesl code.
 Return the amount the indentation changed by."
-  (let ((indent (calculate-cnesl-indent nil))
+  (let ((indent (calculate-nesl-indent nil))
 	beg shift-amt
 	(case-fold-search nil)
 	(pos (- (point-max) (point))))
@@ -143,23 +163,23 @@ Return the amount the indentation changed by."
     (cond ((eq indent nil)
 	   (setq indent (current-indentation)))
 	  ((eq indent t)
-	   (setq indent (calculate-cnesl-indent-within-comment)))
+	   (setq indent (calculate-nesl-indent-within-comment)))
 	  (t
 	   (skip-chars-forward " \t")
 	   ;; Special cases for alignment.
 	   (cond ((and (looking-at "else\\b")
 		       (not (looking-at "else\\s_")))
 		  (setq indent (save-excursion
-				 (cnesl-backward-to-start-of-if)
+				 (nesl-backward-to-start-of-if)
 				 (current-indentation))))
 		 ((and (looking-at "then\\b")
 		       (not (looking-at "then\\s_")))
 		  (setq indent (save-excursion
-				 (cnesl-backward-to-start-of-if)
+				 (nesl-backward-to-start-of-if)
 				 (current-indentation))))
 		 ((looking-at "in\\b")
 		  (setq indent (save-excursion
-				 (cnesl-backward-to-start-of-let)
+				 (nesl-backward-to-start-of-let)
 				 (current-indentation)))))))
     (skip-chars-forward " \t")
     (setq shift-amt (- indent (current-column)))
@@ -175,7 +195,7 @@ Return the amount the indentation changed by."
     shift-amt))
 
 
-(defun calculate-cnesl-indent (&optional parse-start)
+(defun calculate-nesl-indent (&optional parse-start)
   "Return appropriate indentation for current line as C code.
 In usual case returns an integer: the column to indent to.
 Returns nil if line starts inside a string, t if in a comment."
@@ -187,7 +207,7 @@ Returns nil if line starts inside a string, t if in a comment."
 	  containing-sexp)
       (if parse-start
 	  (goto-char parse-start)
-	(beginning-of-cnesl-function))
+	(beginning-of-nesl-function))
       (while (< (point) indent-point)
 	;; TOM: move through at equal levels until we reach POINT
 	(setq parse-start (point))
@@ -233,27 +253,27 @@ Returns nil if line starts inside a string, t if in a comment."
 	       ;; ELSE, try to be more clever
 	       (save-excursion
 		 ;; Look at previous line.
-		 (cnesl-backward-to-noncomment 1)
-		 (let ((retval (cnesl-is-continuation-line)))
+		 (nesl-backward-to-noncomment 1)
+		 (let ((retval (nesl-is-continuation-line)))
 		   ;; if non-nil, then retval is either the keyword of
 		   ;; previous line, or simply 't.
 		   (if retval
 		       (cond
 			((equal retval '("let"))
-			 (+ (current-indentation) cnesl-indent-level))
+			 (+ (current-indentation) nesl-indent-level))
 			((equal retval '("in"))
-			 (+ (current-indentation) cnesl-indent-level))
+			 (+ (current-indentation) nesl-indent-level))
 			((equal retval '("if"))
-			 (+ (current-indentation) cnesl-indent-level))
+			 (+ (current-indentation) nesl-indent-level))
 			((equal retval '("then"))
-			 (+ (current-indentation) cnesl-indent-level))
+			 (+ (current-indentation) nesl-indent-level))
 			((equal retval '("else"))
-			 (+ (current-indentation) cnesl-indent-level))
+			 (+ (current-indentation) nesl-indent-level))
 			(t
 			 (progn
 			   ;; This line is a continuation of a stmt.
 			   ;; Find beginning of this stmt and align to it.
-			   (cnesl-backward-to-start-of-continued-exp 1)
+			   (nesl-backward-to-start-of-continued-exp 1)
 			   (current-indentation))))
 		     ;; ELSE - prev line is NOT a continuation
 		     ;; Align next line to this one
@@ -261,7 +281,7 @@ Returns nil if line starts inside a string, t if in a comment."
 		     )))
 	       ))))))
 	       
-(defun calculate-cnesl-indent-within-comment ()
+(defun calculate-nesl-indent-within-comment ()
   "Return the indentation amount for line, assuming that
 the current line is to be regarded as part of a block comment."
   (let (end star-start)
@@ -279,7 +299,7 @@ the current line is to be regarded as part of a block comment."
       (skip-chars-forward " \t")
       (current-column))))
 
-(defun cnesl-backward-to-noncomment (lim)
+(defun nesl-backward-to-noncomment (lim)
   (let (opoint stop)
     (while (not stop)
       (skip-chars-backward " \t\n\f" lim)
@@ -290,7 +310,7 @@ the current line is to be regarded as part of a block comment."
 	  (forward-char -1)
 	(setq stop t)))))
 
-(defun cnesl-backward-to-start-of-continued-exp (lim)
+(defun nesl-backward-to-start-of-continued-exp (lim)
   (if (memq (preceding-char) '(?\) ?\] ?\}))
       (forward-sexp -1))
   (beginning-of-line)
@@ -298,9 +318,9 @@ the current line is to be regarded as part of a block comment."
       (goto-char (1+ lim)))
   (skip-chars-forward " \t"))
 
-(defun cnesl-backward-to-start-of-if (&optional limit)
+(defun nesl-backward-to-start-of-if (&optional limit)
   "Move to the start of the last ``unbalanced'' if."
-  (or limit (setq limit (save-excursion (beginning-of-cnesl-function)(point))))
+  (or limit (setq limit (save-excursion (beginning-of-nesl-function)(point))))
   (let ((if-level 1)
 	(case-fold-search nil))
     (while (not (zerop if-level))
@@ -313,9 +333,9 @@ the current line is to be regarded as part of a block comment."
 	     (setq if-level 0)
 	     (goto-char limit))))))
 
-(defun cnesl-backward-to-start-of-let (&optional limit)
+(defun nesl-backward-to-start-of-let (&optional limit)
   "Move to the start of the last ``unbalanced'' let."
-  (or limit (setq limit (save-excursion (beginning-of-cnesl-function) (point))))
+  (or limit (setq limit (save-excursion (beginning-of-nesl-function) (point))))
   (let ((if-level 1)
 	(case-fold-search nil))
     (while (not (zerop if-level))
@@ -328,20 +348,20 @@ the current line is to be regarded as part of a block comment."
 	     (setq if-level 0)
 	     (goto-char limit))))))
 
-(defun cnesl-mode ()
-  "Major mode for editing CNESL code."
+(defun nesl-mode ()
+  "Major mode for editing NESL code."
   (interactive)
   (kill-all-local-variables)
-  (use-local-map cnesl-mode-map)
-  (setq major-mode 'cnesl-mode)
-  (setq mode-name "Cnesl")
-  (set-syntax-table cnesl-mode-syntax-table)
-  (cnesl-mode-variables)
-  (run-hooks cnesl-mode-hook))
+  (use-local-map nesl-mode-map)
+  (setq major-mode 'nesl-mode)
+  (setq mode-name "Nesl")
+  (set-syntax-table nesl-mode-syntax-table)
+  (nesl-mode-variables)
+  (run-hooks nesl-mode-hook))
 
 ;;; comments of the form "%<" stay where they are,
 ;;; single "%" comments go to the right margin.
-(defun cnesl-comment-indent ()
+(defun nesl-comment-indent ()
   (if (looking-at "%<")
       (current-column)
     (skip-chars-backward " \t")
@@ -350,7 +370,7 @@ the current line is to be regarded as part of a block comment."
 
 ;;; Are we on a continuation line?
 ;;; Return 't or 'nil, or if keyword, return it
-(defun cnesl-is-continuation-line ()
+(defun nesl-is-continuation-line ()
   (let* ((ch (preceding-char))
 	 (ch-syntax (char-syntax ch)))
     (if (eq ch-syntax ?w)
@@ -368,7 +388,7 @@ the current line is to be regarded as part of a block comment."
 	      (case-fold-search nil)
 	      state
 	      containing-sexp)
-	  (beginning-of-cnesl-function)
+	  (beginning-of-nesl-function)
 	  (while (< (point) indent-point)
 	    ;; TOM: move through at equal levels until we reach POINT
 	    (setq parse-start (point))
@@ -376,17 +396,17 @@ the current line is to be regarded as part of a block comment."
 	  (setq containing-sexp (car (cdr state)))
 	  containing-sexp)))))
     
-(defun cnesl-backward-to-start-of-continued-exp (lim)
+(defun nesl-backward-to-start-of-continued-exp (lim)
 ;;  (if (memq (preceding-char) '( ?\) ?\] ))
 ;;      (forward-sexp -1))
-  (while (cnesl-is-continuation-line)
+  (while (nesl-is-continuation-line)
     (end-of-line 0))
   (beginning-of-line)
   (if (<= (point) lim)
       (goto-char (1+ lim)))
   (skip-chars-forward " \t"))
 
-(defun beginning-of-cnesl-function (&optional arg)
+(defun beginning-of-nesl-function (&optional arg)
   "Move backward to next beginning-of-function.
 With argument, do this that many times.
 Returns t unless search stops due to end of buffer."
@@ -395,7 +415,7 @@ Returns t unless search stops due to end of buffer."
   (and (re-search-backward "^function" nil 'move (or arg 1))
        (progn (beginning-of-line) t)))
 
-(defun end-of-cnesl-function (&optional arg)
+(defun end-of-nesl-function (&optional arg)
   "Move backward to next beginning-of-defun.
 With argument, do this that many times.
 Returns t unless search stops due to end of buffer."
@@ -404,31 +424,37 @@ Returns t unless search stops due to end of buffer."
   (and (re-search-forward "\\$" nil 'move (or arg 1))
        (progn (end-of-line) t)))
 
-(defun cnesl-send-defun (display-flag)
+
+(defun nesl-send-defun-and-maybe-scroll (ignore) 
+  (interactive "P") 
+  (nesl-send-defun nesl-scroll-after-send-defun))
+
+
+(defun nesl-send-defun (display-flag)
   "Send the current defun to the Nesl process made by M-x run-nesl.
 With argument, force redisplay and scrolling of the *nesl* buffer.
-Variable `inferior-cnesl-load-command' controls formatting of
+Variable `inferior-nesl-load-command' controls formatting of
 the `load' form that is set to the Lisp process."
   (interactive "P")
   (or (get-process nesl-process)
       (error "No current lisp process"))
   (save-excursion
-   (end-of-cnesl-function)
+   (end-of-nesl-function)
    (let ((end (point))
-	 (filename (format "/tmp/emlisp%d.cnesl" 
+	 (filename (format "/tmp/emlisp%d.nesl" 
 			   (process-id (get-process nesl-process)))))
-     (beginning-of-cnesl-function)
+     (beginning-of-nesl-function)
      (write-region (point) end filename nil 'nomessage)
      (process-send-string
-      nesl-process (format inferior-cnesl-load-command filename)))
+      nesl-process (format inferior-nesl-load-command filename)))
    (if display-flag
-       (cnesl-redisplay-process-window))
+       (nesl-redisplay-process-window))
    ))
 
 
-;;; After sending an expression to the CNESL sub-process, move point to
+;;; After sending an expression to the NESL sub-process, move point to
 ;;; end of output, and display the process buffer window.
-(defun cnesl-redisplay-process-window ()
+(defun nesl-redisplay-process-window ()
   (let* ((process (get-process nesl-process))
 	 (buffer (process-buffer process))
 	 (w (or (get-buffer-window buffer) (display-buffer buffer)))
@@ -448,10 +474,10 @@ the `load' form that is set to the Lisp process."
       (set-window-start w (point)))
     (set-window-point w end)))
 
-;;; After sending an expression to the CNESL sub-process, 
+;;; After sending an expression to the NESL sub-process, 
 ;;; return interpreter output as a string.
 ;;; Make sure it doesn't change the windows around.
-(defun cnesl-get-process-output ()
+(defun nesl-get-process-output ()
   (save-window-excursion
     (let* ((process (get-process nesl-process))
 	   (buffer (process-buffer process))
@@ -472,11 +498,11 @@ the `load' form that is set to the Lisp process."
       (buffer-substring begin end))))
 
 
-;;; Display the string given in the CNESL pop-up window!
-(defun cnesl-popup-window (s)
+;;; Display the string given in the NESL pop-up window!
+(defun nesl-popup-window (s)
   (let* (
 	 (cbuf (current-buffer))
-	 (buffer (get-buffer-create "*cnesl-popup*"))
+	 (buffer (get-buffer-create "*nesl-popup*"))
 	 (w (or (get-buffer-window buffer) (display-buffer buffer)))
 ;;	 (height (window-height w))
 	 )
@@ -486,41 +512,41 @@ the `load' form that is set to the Lisp process."
     (set-buffer cbuf)
     ))
     
-;;; Send a CNESL function to the pretty printer.
-;;; Display it in the POPUP-WINDOW, or bring up CNESL process window
+;;; Send a NESL function to the pretty printer.
+;;; Display it in the POPUP-WINDOW, or bring up NESL process window
 ;;; if a prefix arg is given.
-(defun cnesl-pretty-print-defun (display-flag)
-  "Send the current function to the CNESL process and pretty-print it
-in a popup window.  Optional prefix arg means to bring up the CNESL
+(defun nesl-pretty-print-defun (display-flag)
+  "Send the current function to the NESL process and pretty-print it
+in a popup window.  Optional prefix arg means to bring up the NESL
 process window instead of a popup."
   (interactive "P")
   (save-excursion
     (let* (
 	   (begin (save-excursion
-		    (beginning-of-cnesl-function)
+		    (beginning-of-nesl-function)
 		    (point)))
 	   (end (save-excursion
-		  (end-of-cnesl-function)
+		  (end-of-nesl-function)
 		  (forward-word -1)	; skip back before $
 		  (point)))
 	   (fn (buffer-substring begin end)) ; extract function def
 	   )
       (process-send-string nesl-process (format "pprint(%s) $\n" fn))))
   (if display-flag
-      (cnesl-redisplay-process-window)
-    (cnesl-popup-window
-     (cnesl-get-process-output))))
+      (nesl-redisplay-process-window)
+    (nesl-popup-window
+     (nesl-get-process-output))))
 
   
-;; Send a CNESL function to be evaluated and find the TYPE returned.
+;; Send a NESL function to be evaluated and find the TYPE returned.
 ;; Modify the current function so that the type is inserted.
-(defun cnesl-insert-function-type ()
+(defun nesl-insert-function-type ()
   (interactive)
   (let* (
 	 (bof)				; beginning of function
 	 (eof				; end of function
 	  (save-excursion
-	    (end-of-cnesl-function)
+	    (end-of-nesl-function)
 	    ;; skip back before $
 	    (forward-word -1)
 	    (point)))
@@ -528,7 +554,7 @@ process window instead of a popup."
 	 (eot)				; end of type information
 	 )
     (save-excursion			; find various points in function
-	(beginning-of-cnesl-function)
+	(beginning-of-nesl-function)
 	(setq bof (point))
 	(forward-word 2)		; skip "function NAME"
 	(forward-sexp 1)		; skip arg list
@@ -541,13 +567,13 @@ process window instead of a popup."
 	    (forward-char -1)		; before the =
 	    (setq eot (point))))
 	)
-    (process-send-string		; send the DEFUN to CNESL interpreter
+    (process-send-string		; send the DEFUN to NESL interpreter
      nesl-process
      (format "%s $\n" (buffer-substring bof eof)))
 			 
     (let* (
-	  (output (cnesl-get-process-output))
-	  (type   (cnesl-parse-defun-output output))
+	  (output (nesl-get-process-output))
+	  (type   (nesl-parse-defun-output output))
 	  )
       (if type				; if non-nil, replace type clause
 	  (progn
@@ -559,10 +585,10 @@ process window instead of a popup."
 
 ;; If there is no error, return the type portion of a defun or NIL
 ;; if there was an error
-(defun cnesl-parse-defun-output (s)
+(defun nesl-parse-defun-output (s)
   (save-window-excursion
-    (set-buffer (get-buffer-create "*cnesl junk buffer*"))
-    (set-syntax-table cnesl-mode-syntax-table) ; to parse words like CNESL
+    (set-buffer (get-buffer-create "*nesl junk buffer*"))
+    (set-syntax-table nesl-mode-syntax-table) ; to parse words like NESL
     (erase-buffer)
     (insert s)				; write it here
     (beginning-of-buffer)		; back to the top
